# BEGIN COPYRIGHT BLOCK
# Copyright (C) 2006 Red Hat, Inc.
# All rights reserved.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
# END COPYRIGHT BLOCK

AC_MSG_CHECKING(for --with-httpd)
AC_ARG_WITH(httpd,
            AS_HELP_STRING([--with-httpd=PATH],
                           [Full path of Apache binary.  Configure will usually find the right one, but if it does not, use this to specify the correct binary.]),
[
  if test -x "$withval"
  then
    AC_MSG_RESULT([using $withval])
    HTTPD="$withval"
  else
    echo
    AC_MSG_ERROR([$withval not found])
  fi
],
AC_MSG_RESULT(no))

if test -z "$HTTPD" ; then
    AC_PATH_PROG([HTTPD], [httpd.worker], [],
                 [$PATH:/opt/hpws/apache/bin:/usr/local/apache/sbin:/usr/local/apache2/sbin:/usr/sbin])
    if test -z "$HTTPD" -o ! -x "$HTTPD" ; then
        AC_PATH_PROG([HTTPD], [httpd], [],
                     [$PATH:/opt/hpws/apache/bin:/usr/local/apache/sbin:/usr/local/apache2/sbin:/usr/sbin])
    fi
    if test -z "$HTTPD" -o ! -x "$HTTPD" ; then
        AC_MSG_ERROR([Apache2 httpd server not found])
    fi
fi

httpd_root=`$HTTPD -V | grep HTTPD_ROOT | cut -f2 -d=`
httpd_root=`eval echo $httpd_root`
httpd_conf_rel=`$HTTPD -V | grep SERVER_CONFIG_FILE | cut -f2 -d=`
httpd_conf_rel=`eval echo $httpd_conf_rel`
# Server version: Apache/2.2.2
verstr='Server version: Apache/'
httpd_ver=`$HTTPD -v | grep "Server version:" | sed -e "s,$verstr,,"`
case $httpd_ver in
    2.2*) APACHE22=1 ;;
    *) APACHE22= ;;
esac

httpdconf=${httpd_root}/${httpd_conf_rel}

mimemagic=`grep MIMEMagicFile $httpdconf|grep -v \^# | awk '{print $2}'`
if test ! -f "$mimemagic" ; then
# assume relative to root
    mimemagic=${httpd_root}/${mimemagic}
fi

# check for mime.types file
httpdconfdir=`dirname $httpdconf`
if test ! -f $httpdconfdir/mime.types ; then
    httpdconfdir="/etc"
    if test ! -f $httpdconfdir/mime.types ; then
        AC_MSG_ERROR([mime.types file not found])
    fi
fi

# check for --with-apxs
AC_MSG_CHECKING(for --with-apxs)
AC_ARG_WITH(apxs,
            AS_HELP_STRING([--with-apxs=PATH],
                           [Path to apxs]),
[
  if test -x "$withval"
  then
    AC_MSG_RESULT([using $withval])
    APXS=$withval
  else
    echo
    AC_MSG_ERROR([$withval not found or not executable])
  fi
],
AC_MSG_RESULT(no))

if test -z "$APXS" ; then
    # first look for APXS in same dir as HTTPD
    apachedir=`dirname $HTTPD`
    if test -x "$apachedir/apxs" ; then
        APXS="$apachedir/apxs"
    else
        AC_PATH_PROG([APXS], [apxs], [],
                     [$PATH:/opt/hpws/apache/bin:/usr/local/apache/sbin:/usr/local/apache2/sbin:/usr/sbin])
    fi
    if test -z "$APXS" ; then
        AC_MSG_ERROR([Apache2 apxs program not found])
    fi
fi

AC_CHECKING(for apr-config)
# check for --with-apr-config
AC_MSG_CHECKING(for --with-apr-config)
AC_ARG_WITH(apr-config,
            AS_HELP_STRING([--with-apr-config],
                           [Use apr-config to determine the APR directory]),
[
  if test -x "$withval"
  then
    AC_MSG_RESULT([using $withval])
    APR_CONFIG=$withval
  fi
],
AC_MSG_RESULT(no))

if test -z "$APR_CONFIG" ; then
    # first look for APR_CONFIG in the bin dir if HTTPD is in the sbin dir
    apachedir=`dirname $HTTPD`
    parentdir=`dirname $apachedir`
    if test -x "$parentdir/bin/apr-1-config" ; then
        APR_CONFIG="$parentdir/bin/apr-1-config"
    elif test -x "$parentdir/bin/apr-config" ; then
        APR_CONFIG="$parentdir/bin/apr-config"
    else
        AC_PATH_PROGS(APR_CONFIG, apr-1-config apr-config, NO_APR_CONFIG,
                      [$PATH:/opt/hpws/apache/bin:/usr/local/apache/bin:/usr/bin])
    fi
    if test -z "$APR_CONFIG" ; then
        AC_MSG_ERROR([Apache2 apr-config program not found])
    fi
fi

if test -z "$moddir" ; then
    if test -n "$APXS" -a -x "$APXS" ; then
        moddir=`$APXS -q LIBEXECDIR`
    fi

    if test -z "$moddir" ; then
        moddir='$(libdir)/httpd/modules'
    fi
fi
